embassy-stm32

Crates

git

Versions

stm32u599vi

Flavors

FMAC

Struct FMAC 

pub struct FMAC { /* private fields */ }
FMAC peripheral

Implementations

Source

impl FMAC

pub const unsafe fn steal() -> Peri<'static, Self>

Unsafely create an instance of this peripheral out of thin air.

Safety

You must ensure that you’re only using one instance of this type at a time.